@@ -21,7 +21,7 @@ namespace Rivet {
 
     void init() {
       FinalState fs;
-      FastJets jetpro(fs, FastJets::KT, 0.7);
+      FastJets jetpro(fs, FastJets::ANTIKT, 0.4);
       addProjection(jetpro, "Jets");
 
       MC_JetAnalysis::init();
